/*
 * kroots.cpp
 *
 * Copyright (C) 2008 Jonathan Fine (were.Vire@gmail.com)
 *
 * This file is part of KRoots.
 *
 * KRoots is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * KRoots is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with KRoots.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "kroots.h"
#include "krootsview.h"
#include "settings.h"

#include <KConfigDialog>

#include <KAction>
#include <KActionCollection>
#include <KStandardAction>
#include <KAcceleratorManager>
#include <KMenuBar>

#include <KLocale>

KRoots::KRoots()
	: KXmlGuiWindow(),
	  mView(new KRootsView(this))
{
	setCentralWidget(mView);
	setupActions();
	setupGUI();
	
	//Get rid of stupid settings menus that are not needed
	foreach(QAction * item, menuBar()->actions().at(1)->menu()->actions())
		if (!item->text().contains(i18n("KRoots")))
			delete item;
	
	//kill the status bar
	QMainWindow::setStatusBar(0);
}

KRoots::~KRoots()
{
}

void KRoots::setupActions()
{
	KStandardAction::quit(qApp, SLOT(closeAllWindows()), actionCollection());
	KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
	
	KAction *a = actionCollection()->addAction("clear");
	a->setText(i18n("Clear Graph"));
	connect( a,SIGNAL(triggered( bool)), mView, SLOT(clear()));
	a->setEnabled( true );
	
	a = actionCollection()->addAction("draw");
	a->setText(i18n("Draw the Roots"));
	connect( a,SIGNAL(triggered( bool)), mView, SLOT(drawPolygon()));
	a->setEnabled( true );
}

void KRoots::optionsPreferences()
{
	if ( KConfigDialog::showDialog( "settings" ) )  return;
	
	KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
	QWidget *generalSettingsDlg = new QWidget;
	ui_prefs_base.setupUi(generalSettingsDlg);
	dialog->addPage(generalSettingsDlg, i18n("General"), "preferences-other");
	
	connect(dialog, SIGNAL(settingsChanged(QString)), mView, SLOT(settingsChanged()));
	dialog->setAttribute( Qt::WA_DeleteOnClose );
	dialog->show();
}

#include "kroots.moc"
